// ---------------------------------------------------------------------------
// deploy_repeat.cs -- Version 1.0 -- January 8, 2001
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Continue trying to deploy an item for a few seconds while you hold your
// "use(backpack);" key
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\deploy_repeat.cs", "1.0", "Lorne Laliberte", "Jan 8, 2001");

include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\item_events.cs");
include("writer\\save.cs");
include("writer\\schedule.cs");
include("writer\\you_died.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_deploy_repeat.cs file

    // Time in seconds between each deploy attempt (repeat rate)
    $DeployRepeat::interval = "0.1";

    // Press this key to use your backpack.  If you're carrying a deployable
    // pack, you can hold this key down to keep trying to deploy.
    // Note: this key can replace your normal "use(backpack);" key
    //bind(keyboard0, make, "q", to, "DeployRepeat::pressed();");
    //bind(keyboard0, break, "q", to, "DeployRepeat::released();");

// ---------------------------------------------------------------------------

WriterPrefs::load("deploy_repeat");


function DeployRepeat::pressed()
{
    %pack = getMountedItem(1);

    if($Inv::isDeployable[%pack])
    {
        $DeployRepeat::keepTrying = true;
        DeployRepeat::keepTrying(%pack);
    }    
    else
    {
        use(backpack);
    }
}

function DeployRepeat::released()
{
    $DeployRepeat::keepTrying = false;
    schedule::cancel(deploy_repeat);
    $DeployRepeat::previous_msg = "";
}


function DeployRepeat::keepTrying(%itemtype)
{
    if($DeployRepeat::keepTrying)
    {
        useType(%itemtype);
        schedule::add("DeployRepeat::keepTrying(" @ %itemtype @ ");", $DeployRepeat::interval, deploy_repeat);
    }
}

function DeployRepeat::stop()
{
    $DeployRepeat::keepTrying = false;
    schedule::cancel(deploy_repeat);
    $DeployRepeat::previous_msg = "";
    return;
}

// mute repeated messages so we don't spam our chat hud
function DeployRepeat::mute(%msg)
{
echo(%msg);
    if(%msg == $DeployRepeat::previous_msg)
        return mute;

    $DeployRepeat::previous_msg = %msg;
    return;
}


function deploy_repeat::save()
{
    AddExportText("    // Time in seconds between each deploy attempt (repeat rate)");
    ExportSetting("    $DeployRepeat::interval","0.1");
    AddExportText("");
    AddExportText("    // Press this key to use your backpack.  If you're carrying a deployable");
    AddExportText("    // pack, you can hold this key down to keep trying to deploy.");
    AddExportText("    // Note: this key can replace your normal \"use(backpack);\" key");

    ExportBind("DeployRepeat::Pressed();", "//bind(keyboard0, make, \"q\", TO, \"DeployRepeat::Pressed();\");");
    ExportBind("DeployRepeat::Released();", "//bind(keyboard0, break, \"q\", TO, \"DeployRepeat::Released();\");");
}

WriterPrefs::save("deploy_repeat");

function deploy_repeat::init()
{
    needs("writer\\deploy_repeat.cs", "writer\\event.cs 2.7",
                                      "writer\\inventory.cs 3.3",
                                      "writer\\item_events.cs 2.12",
                                      "writer\\save.cs 2.3",
                                      "writer\\schedule.cs 1.3",
                                      "writer\\you_died.cs 1.6");

    Event::Attach(eventDeployed, "DeployRepeat::stop();");
    Event::Attach(eventYouDied, "DeployRepeat::stop();");

    Event::Attach(eventDeployTooClose, "DeployRepeat::mute(TooClose);");
    Event::Attach(eventDeployTooFar, "DeployRepeat::mute(TooFar);");
    Event::Attach(eventDeployItemInTheWay, "DeployRepeat::mute(ItemInTheWay);");
    Event::Attach(eventDeployInterference, "DeployRepeat::mute(Interference);");
    Event::Attach(eventDeployFrequencyOverload, "DeployRepeat::mute(FrequencyOverload);");
    Event::Attach(eventDeployItemLimitReached, "DeployRepeat::mute(ItemLimitReached);");
    Event::Attach(eventDeployOnTerrainOrBuildings, "DeployRepeat::mute(TerrainOrBuildings);");
    Event::Attach(eventDeployOnFlatSurfaces, "DeployRepeat::mute(FlatSurfaces);");
}
Event::Attach(writerInit, "deploy_repeat::init();");

if(!$UsingWriterLoader) deploy_repeat::init();
